### Name: vode
### Title: General solver for ordinary differential equations (ODE)
### Aliases: vode
### Keywords: math

### ** Examples
# The famous Lorenz equations: chaos in the earth's atmosphere
# Lorenz 1963. J. Atmos. Sci. 20, 130-141.

chaos<-function(t,state,parameters)
  {
  with(as.list(c(state)),{

    dx     <- -8/3*x+y*z
    dy     <- -10*(y-z)
    dz     <- -x*y+28*y-z

    list(c(dx,dy,dz))            })

 }  # end of model

state <-c(x=1, y=1, z=1)
times <-seq(0,100,0.01)
out   <-as.data.frame(vode(state,times,chaos,0))

plot(out$x,out$y,type="l",main="Lorenz butterfly")



